@@ -2,7 +2,7 @@
 /**
  *  @brief Implementation of SimulationResult
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -288,12 +288,9 @@ Graph SimulationSensitivityAnalysis::drawImportanceFactorsRange(const Bool proba
         try
         {
           importanceFactors = getTransformation()(accumulator / accumulated).normalizeSquare();
-          const Point ref(computeImportanceFactors(currentThreshold));
           for (UnsignedInteger j = 0; j < inputDimension; ++j)
           {
-            Point point(2);
-            point[0] = xValue;
-            point[1] = 100.0 * importanceFactors[j];
+            const Point point = {xValue, 100.0 * importanceFactors[j]};
             dataCollection[j].add(point);
           }
         }
