@@ -29,7 +29,6 @@
 #include "openturns/OSS.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-#include "openturns/Matrix.hxx"
 #include "openturns/MatrixImplementation.hxx"
 #include "openturns/NormalCopula.hxx"
 #include "openturns/ResourceMap.hxx"
@@ -80,7 +79,6 @@ Normal::Normal(const Point & mean,
                            , R
                            , 1.0)
   , logNormalizationFactor_((-1.0 * mean.getDimension()) * SpecFunc::LOGSQRT2PI)
-  , hasIndependentCopula_(false)
 {
   setName("Normal");
   // Compute the range, the upper class cannot do it.
@@ -102,7 +100,6 @@ Normal::Normal(const Point & mean,
                            , CorrelationMatrix(mean.getDimension())
                            , 1.0)
   , logNormalizationFactor_((-1.0 * mean.getDimension()) * SpecFunc::LOGSQRT2PI)
-  , hasIndependentCopula_(false)
 {
   setName("Normal");
   UnsignedInteger dimension = mean.getDimension();
@@ -236,7 +233,8 @@ Scalar Normal::computePDF(const Scalar x) const
 Scalar Normal::computePDF(const Point & point) const
 {
   const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension (" << point.getDimension()
+        << ") incompatible with the distribution (" << dimension << ").";
   // Special case for dimension 1
   if (dimension == 1) return computePDF(point[0]);
   return EllipticalDistribution::computePDF(point);
@@ -251,7 +249,8 @@ Scalar Normal::computeCDF(const Scalar x) const
 Scalar Normal::computeCDF(const Point & point) const
 {
   const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension (" << point.getDimension()
+        << ") incompatible with the distribution (" << dimension << ").";
   // Special case for dimension 1
   if (dimension == 1) return computeCDF(point[0]);
   // Normalize the point to use the standard form of the multivariate normal distribution
@@ -398,7 +397,8 @@ Scalar Normal::computeComplementaryCDF(const Scalar x) const
 Scalar Normal::computeComplementaryCDF(const Point & point) const
 {
   const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension (" << point.getDimension()
+        << ") incompatible with the distribution (" << dimension << ").";
   // Special case for dimension 1
   if (dimension == 1) return computeComplementaryCDF(point[0]);
   return EllipticalDistribution::computeComplementaryCDF(point);
@@ -425,6 +425,7 @@ Complex Normal::computeCharacteristicFunction(const Point & x) const
 
 Complex Normal::computeLogCharacteristicFunction(const Scalar x) const
 {
+  if (dimension_ != 1) throw InvalidDimensionException(HERE) << "Normal: cannot use computeCharacteristicFunction with dimension > 1";
   return Complex(-0.5 * sigma_[0] * sigma_[0] * x * x, mean_[0] * x);
 }
 
@@ -477,7 +478,7 @@ Scalar Normal::computeProbability(const Interval & interval) const
     const UnsignedInteger candidateNumber = ResourceMap::GetAsUnsignedInteger( "Normal-MarginalIntegrationNodesNumber" );
     if (candidateNumber > maximumNumber) LOGWARN(OSS() << "Warning! The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of PDF evaluations. It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"Normal-MaximumNumberOfPoints\"");
     setIntegrationNodesNumber(std::min(maximumNumber, candidateNumber));
-    return ContinuousDistribution::computeProbability(interval);
+    return DistributionImplementation::computeProbability(interval);
   }
   // For very large dimension, use a MonteCarlo algorithm
   LOGWARN(OSS() << "Warning, in Normal::computeProbability(), the dimension is very high. We will use a Monte Carlo method for the computation with a relative precision of 0.1% at 99% confidence level and a maximum of " << 10 * ResourceMap::GetAsUnsignedInteger( "Normal-MaximumNumberOfPoints" ) << " realizations. Expect a long running time and a poor accuracy for low values of the CDF...");
@@ -629,17 +630,25 @@ Scalar Normal::computeConditionalQuantile(const Scalar q,
   const UnsignedInteger conditioningDimension = y.getDimension();
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if ((q < 0.0) || (q > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile for a probability level outside of [0, 1]";
-  // Special case when no contitioning or independent copula
+  // Special case when no conditioning or independent copula
   if ((conditioningDimension == 0) || hasIndependentCopula()) return mean_[conditioningDimension] + sigma_[conditioningDimension] * DistFunc::qNormal(q);
   // General case
-  Scalar meanRos = 0.0;
-  const Scalar sigmaRos = 1.0 / inverseCholesky_(conditioningDimension, conditioningDimension);
-  for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
+  const UnsignedInteger partialDimension = conditioningDimension + 1;
+  UnsignedInteger start = 0;
+  UnsignedInteger stop = partialDimension;
+  UnsignedInteger shift = 0;
+  MatrixImplementation inverseCholeskyPartial(partialDimension, partialDimension);
+  for (UnsignedInteger i = 0; i < partialDimension; ++ i)
   {
-    meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
+    std::copy(inverseCholesky_.getImplementation()->begin() + start,
+              inverseCholesky_.getImplementation()->begin() + stop,
+              inverseCholeskyPartial.begin() + shift);
+    start += dimension_ + 1;
+    stop += dimension_;
+    shift += partialDimension + 1;
   }
-  meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
-  return meanRos + sigmaRos * DistFunc::qNormal(q);
+  const Point iCholQ(inverseCholeskyPartial.solveLinearSystemTri(DistFunc::qNormal(Point(partialDimension, q))));
+  return mean_[conditioningDimension] + iCholQ[conditioningDimension];
 }
 
 Point Normal::computeSequentialConditionalQuantile(const Point & q) const
